-- Author: VertexFloat
-- Date: 22.11.2021
-- Version: Farming Simulator 22, 1.0.0.0
-- Copyright (C): VertexFloat, All Rights Reserved
-- CutterFix specialization

CutterFix = {}
  
function CutterFix.prerequisitesPresent(specializations)
	return true
end

function CutterFix.registerOverwrittenFunctions(vehicleType)
	SpecializationUtil.registerOverwrittenFunction(vehicleType, "startThreshing", CutterFix.startThreshing)
	SpecializationUtil.registerOverwrittenFunction(vehicleType, "stopThreshing", CutterFix.stopThreshing)
end

function CutterFix:startThreshing()
	local spec = self.spec_combine
	
	if spec.numAttachedCutters > 0 then
		local allowLowering = not self:getIsAIActive() or not self.rootVehicle:getAIFieldWorkerIsTurning()
		
		for _, cutter in pairs(spec.attachedCutters) do
			cutter:setIsTurnedOn(true, true)
		end
		
		if spec.threshingStartAnimation ~= nil and self.playAnimation ~= nil then
			self:playAnimation(spec.threshingStartAnimation, spec.threshingStartAnimationSpeedScale, self:getAnimationTime(spec.threshingStartAnimation), true)
		end
		
		if self.isClient then
			g_soundManager:stopSample(spec.samples.stop)
			g_soundManager:stopSample(spec.samples.work)
			g_soundManager:playSample(spec.samples.start)
			g_soundManager:playSample(spec.samples.work, 0, spec.samples.start)
		end
		
		SpecializationUtil.raiseEvent(self, "onStartThreshing")
	end
end

function CutterFix:stopThreshing()
	local spec = self.spec_combine
	
	if self.isClient then
		g_soundManager:stopSample(spec.samples.start)
		g_soundManager:stopSample(spec.samples.work)
		g_soundManager:playSample(spec.samples.stop)
	end
	
	self:setCombineIsFilling(false, false, true)
	
	for cutter, _ in pairs(spec.attachedCutters) do
		cutter:setIsTurnedOn(false, true)
	end
	
	if spec.threshingStartAnimation ~= nil and spec.playAnimation ~= nil then
		self:playAnimation(spec.threshingStartAnimation, -spec.threshingStartAnimationSpeedScale, self:getAnimationTime(spec.threshingStartAnimation), true)
	end
	
	SpecializationUtil.raiseEvent(self, "onStopThreshing")
end